(v0.4.3)=
### 0.4.3 {small}`2018-02-09`

- {func}`~scanpy.pl.clustermap`: heatmap from hierarchical clustering,
  based on {func}`seaborn.clustermap` {cite:p}`Waskom2016` {smaller}`A Wolf`
- only return {class}`matplotlib.axes.Axes` in plotting functions of `sc.pl`
  when `show=False`, otherwise `None` {smaller}`A Wolf`
